<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="供应商">
              <el-select v-model="querys[0].value" clearable filterable allow-create style="width: 100%"
                placeholder="请选择供应商">
                <el-option v-for="item in gys" :key="item.id" :label="item.name" :value="item.name">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="状态">
              <el-select v-model="querys[2].value" clearable placeholder="请选择">
                <el-option label="已入库" value="2"></el-option>
                <el-option label="部分入库" value="3"></el-option>
                <!-- <el-option label="签收未入库" value="1"></el-option> -->
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="所属仓库">
              <el-select v-model="querys[3].value" clearable filterable allow-create style="width: 100%"
                placeholder="请选择仓库">
                <el-option v-for="item in warehouses" :key="item.value" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <!-- <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button
            slot="reference"
            :disabled="!multipleSelection.length"
            icon="el-icon-delete"
            type="danger"
            style="margin-left: 10px"
            >删除</el-button
          >
        </el-popconfirm> -->

        <!-- <ZUpload
                    style="margin-left: 10px"
                    btn-label="导入"
                    :action="
                        portal + '/manager/material/into/warehouse/importdata'
                    "
                    @after-upload="afterUpload"
                /> -->
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column prop="code" label="入库单号" show-overflow-tooltip />
        <el-table-column prop="orderName" label="订单标题" min-width="100" show-overflow-tooltip />
        <el-table-column prop="supplierName" label="供应商" min-width="100" show-overflow-tooltip />
        <el-table-column prop="applicantName" label="签收人" width="100" show-overflow-tooltip />
        <el-table-column prop="orgName" label="签收部门" show-overflow-tooltip />
        <!-- <el-table-column prop="approvedDate" label="签收时间" show-overflow-tooltip /> -->
        <el-table-column prop="signAmount" label="签收金额" width="100" show-overflow-tooltip />
        <el-table-column label="状态" width="100" prop="status">
          <template slot-scope="scope">
            <el-tag v-if="scope.row.status == '2'" type="success">已入库</el-tag>
            <el-tag v-else-if="scope.row.status == '1'" type="info">签收未入库</el-tag>
            <el-tag v-else-if="scope.row.status == '3'" type="primary">部分入库</el-tag>
          </template>
        </el-table-column>
        <el-table-column prop="warehouse" width="110" label="入库仓库" show-overflow-tooltip
          :formatter="formartWarehouseName" />
        <el-table-column prop="inoutDate" label="入库时间" show-overflow-tooltip />
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <MaterialIntoWareHoseManageDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import materialIntoManage from '@/api/manager/material/materialIntoWarehouseManage.js'
import MaterialIntoWareHoseManageDialog from '@/views/Manage/material/components/MaterialIntoWareHoseManageDialog.vue'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import ZUpload from '@/views/Manage/components/ZUpload.vue'

export default {
  name: 'MaterialIntoManage',
  components: {
    MaterialIntoWareHoseManageDialog,
    ZUpload
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/material/signWarehouse/'
      },
      userSelectOptions: [],
      gys: [],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'wn.supplier_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'applicant_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'status_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warehouse_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      warehouses: [],
      sorter: [
        {
          direction: 'DESC',
          property: 'create_time_'
        }
      ]
    }
  },
  created() {
    this.commonApiData()
    this.warehouses = dictContracts.getDictItemsFromCache('cmgt_ckmc')
    materialIntoManage.findAllCustom(res => {
      this.gys = res
    })
  },
  mounted() { },
  methods: {
    commonApiData() {
      CommonApi.loadSelectOptions(
        {
          name: 'manageCommonService.getAllUsers',
          query: '96240625-934F-490B-8AA6-0BC775B18468'
        },
        res => {
          this.userSelectOptions = res
        }
      )
    },
    // 重置
    clearQuerys() {
      this.querys.forEach(item => (item.value = ''))
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.querys.forEach(item => {
        if (item.value !== undefined) {
          this.queryParam.querys.push(item)
        }
      })
      this.queryParam.sorter = this.sorter
      materialIntoManage.loadIntoWarehouse(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },

    afterUpload(response) {
      this.$message.success(response.msg)
      this.loadData(1)
    },
    // 修改
    handleUpdate(row) {
      materialIntoManage.getDetailById(row.id).then(res => {
        this.$refs.formModal.Update(res)
      })
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    formartWarehouseName(row, column, cellValue, index) {
      var obj = this.warehouses.find(function (item) {
        if (item.value === row.warehouse) {
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
